@@ -1,8 +1,9 @@
 #ifndef ___MEANANOMALY_H___
 #define ___MEANANOMALY_H___
 
-#include <R.h>
-#include <Rinternals.h>
+#include <Rcpp.h>
+//#include <R.h>
+//#include <Rinternals.h>
 #include <vector>
 
 std::vector<int> MeanAnomaly(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP);
