@@ -1,16 +1,22 @@
-#include <R.h>
-#include <Rinternals.h>
-#include <Rmath.h> 
-#include <math.h> 
-#include <stdlib.h>
-#include <float.h>
-#include <stdbool.h>
+
+
+//#include <R.h>
+//#include <Rinternals.h>
+//#include <Rmath.h> 
+//#include <math.h> 
+//#include <stdlib.h>
+//#include <float.h>
+//#include <stdbool.h>
 
 #include "Functions.h"
 
 #include "user_interupt.h"
 #include "check_user_interrupt.h"
 
+#include <cfloat>
+#include <limits>
+#include <cmath>
+
 
 namespace anomaly
 {
@@ -106,7 +112,7 @@ void updatewithobservation(int ii, struct orderedobservationlist *list, double *
 		{
 			varianceestimate = DBL_MIN;
 		}
-
+		
 		current->segmentcost = current->optimalcostofprevious + factor*(1+log(varianceestimate)) + penaltychange[factor - 1];
 		current = current->next;
 
@@ -125,14 +131,17 @@ void findoptimaloption(int ii, struct orderedobservationlist *list, int minsegle
 	bestcut= &(list[ii-1]);
 	option = 0;
 
-	squareestimate  = list[ii].observationsquared; 
+	squareestimate  = list[ii].observationsquared;
 
-	if(squareestimate <= DBL_MIN)
-	{
-		squareestimate = DBL_MIN;
-	}
-
-	scoreanomalous = list[ii].optimalcostofprevious + 1 + log(squareestimate) + penaltyoutlier;
+	//if(squareestimate <= DBL_MIN)
+	//  {
+	//    squareestimate = DBL_MIN;
+	//  }
+	
+	
+	squareestimate += std::max(std::numeric_limits<double>::min(),std::exp(-(1.0 + penaltyoutlier)));
+	
+	scoreanomalous = list[ii].optimalcostofprevious + 1 + std::log(squareestimate) + penaltyoutlier;
 	
 	if (scoreanomalous < optimalscore)
 	{
